@@ -3,6 +3,9 @@ import os
 import gen3.cli.auth as auth
 import gen3.cli.pfb as pfb
 import gen3.cli.wss as wss
+import gen3.cli.discovery as discovery
+import gen3.cli.configure as configure
+import gen3.cli.objects as objects
 import gen3
 
 
@@ -24,7 +27,7 @@ class AuthFactory:
     "--auth",
     "auth_config",
     default=os.getenv("GEN3_API_KEY", None),
-    help="""authentication source: 
+    help="""authentication source:
     "idp://wts/<idp>" is an identity provider in a Gen3 workspace,
     "accesstoken:///<token>" is an access token,
     otherwise a path to an api key or basename of key under ~/.gen3/;
@@ -39,7 +42,7 @@ class AuthFactory:
 )
 @click.pass_context
 def main(ctx=None, auth_config=None, endpoint=None):
-    """Gen3 sdk commands"""
+    """Gen3 Command Line Interface"""
     ctx.ensure_object(dict)
     ctx.obj["auth_config"] = auth_config
     ctx.obj["endpoint"] = endpoint
@@ -49,5 +52,8 @@ def main(ctx=None, auth_config=None, endpoint=None):
 main.add_command(auth.auth)
 main.add_command(pfb.pfb)
 main.add_command(wss.wss)
+main.add_command(discovery.discovery)
+main.add_command(configure.configure)
+main.add_command(objects.objects)
 
 main()
