@@ -1,6 +1,7 @@
 import logging
 import sys
 import re
+import requests
 
 from urllib.parse import urlunsplit
 from urllib.parse import urlencode
@@ -18,6 +19,18 @@ URL_FORMAT = r"^.*$"
 AUTHZ_FORMAT = r"^.*$"
 
 
+def raise_for_status(response):
+    try:
+        response.raise_for_status()
+    except requests.HTTPError as exception:
+        print(
+            "Error: status code {}; details:\n{}".format(
+                response.status_code, response.text
+            )
+        )
+        raise
+
+
 def append_query_params(original_url, **kwargs):
     """
     Add additional query string arguments to the given url.
@@ -113,13 +126,11 @@ def _verify_format(s, format):
 
 def _standardize_str(s):
     """
-    Remove unnecessary spaces, commas
+    Remove unnecessary spaces
 
     Ex. "abc    d" -> "abc d"
-        "abc, d" -> "abc d"
     """
     memory = []
-    s = s.replace(",", " ")
     res = ""
     for c in s:
         if c != " ":
@@ -131,6 +142,30 @@ def _standardize_str(s):
     return res
 
 
+def get_urls(raw_urls_string):
+    """
+    Given raw string like "['gs://topmed-irc-share/genomes/NWD293573%20file.b38.irc.v1.cram', 's3://nih-nhlbi-datacommons/NWD293573.b38.irc.v1.cram']"
+    return a list of urls:
+
+    [
+        "gs://topmed-irc-share/genomes/NWD293573 file.b38.irc.v1.cram",
+        "s3://nih-nhlbi-datacommons/NWD293573.b38.irc.v1.cram"
+    ]
+    """
+    return [
+        element.strip()
+        .replace("'", "")
+        .replace('"', "")
+        .replace("%20", " ")
+        .rstrip(",")
+        for element in _standardize_str(raw_urls_string)
+        .strip()
+        .lstrip("[")
+        .rstrip("]")
+        .split(" ")
+    ]
+
+
 # Default settings to control usage of backoff library.
 DEFAULT_BACKOFF_SETTINGS = {
     "on_backoff": log_backoff_retry,
